{*******************************************************************************
* Unit      : TSLockPK Demostration program "LockTest"                         *
********************************************************************************
* Purpose   : Demonstration/Example program for the SLockPK component          *
*             This program is intended to provide SLockPK users with ideas     *
*             and examples how to use the SLockPK component to achieve         *
*             successful results. You are at liberty to use sections of this   *
*             example code in your applications when you have purchased a      *
*             license for SLockPK                                              *
********************************************************************************
* Copyright : This software  is copyright TSM Inc. 1998-1999                   *
*             This source code may not be distributed to third parties in      *
*             or in part without the written permission of TSM Inc.            *
*             All rights reserved. Liability limited to replacement of         *
*             this original source code in the case of loss or damage because  *
*             the use or misuse of this software.                              *
********************************************************************************
* Version   : 14.05.98  - 1.00  Original Version                               *
*             22.04.99  - 2.00  PK version "SLockPK"                           *
********************************************************************************
* Switches  : None                                                             *
*******************************************************************************}
unit RegFrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ShellApi;

type
  TfrmRegister = class(TForm)
    grpRegInfo: TGroupBox;
    pnlButtons: TPanel;
    lblChallenge: TLabel;
    edtChallengeString: TEdit;
    lblUnlock: TLabel;
    edtUnlock: TEdit;
    btnDone: TButton;
    edtRegName: TEdit;
    lblName: TLabel;
    btnSetName: TButton;
    bvlStep1: TBevel;
    bvlStep3: TBevel;
    lblStep1: TLabel;
    lblSeeHelpFile: TLabel;
    btnRegister: TButton;
    lblStep3: TLabel;
    btnPurchase: TButton;
    bvlStep2: TBevel;
    lblStep2: TLabel;
    btnTSMWeb: TButton;
    procedure btnDoneClick(Sender: TObject);
    procedure btnRegisterClick(Sender: TObject);
    procedure btnSetNameClick(Sender: TObject);
    procedure edtUnlockChange(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure edtRegNameChange(Sender: TObject);
    procedure btnPurchaseClick(Sender: TObject);
    procedure btnTSMWebClick(Sender: TObject);
  end;

var
  frmRegister: TfrmRegister;

implementation

uses
     SlockFrm;

{$R *.DFM}

{*******************************************************************************
* Procedure : btnDoneClick                                                     *
********************************************************************************
* Purpose   : Closes the window                                                *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnDoneClick(Sender: TObject);
begin
     Close;
end; {TfrmRegister.btnDoneClick}

{*******************************************************************************
* Procedure : btnRegisterClick                                                 *
********************************************************************************
* Purpose   : Attempts to register the application by feeding the unlock       *
*             code into SLock                                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnRegisterClick(Sender: TObject);
begin
     frmMain.Slock1.RegName := edtRegName.Text;
     frmMain.Slock1.RegisterNow(edtUnlock.Text);
end; {TfrmRegister.btnRegisterClick}

{*******************************************************************************
* Procedure : btnSetNameClick                                                  *
********************************************************************************
* Purpose   : Sets the name of the registered user to allow an ID-String to    *
*             be calculated, which includes the user name                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnSetNameClick(Sender: TObject);
begin
     if (Length(edtRegName.Text) > 0) then
     begin
          frmMain.Slock1.RegName := edtRegName.Text;
          edtChallengeString.Text := frmMain.Slock1.ChallengeString;
          edtChallengeString.Enabled := True;
          edtUnlock.Enabled := True;
          edtUnlock.SetFocus;
     end
     else
     begin
          edtChallengeString.Enabled := False;
          edtUnlock.Enabled := False;
     end; {if}
end; {TfrmRegister.btnSetNameClick}

{*******************************************************************************
* Procedure : edtUnlockChange                                                  *
********************************************************************************
* Purpose   : Sets the state of the Register button depending on the contents  *
*             of unlock text field                                             *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.edtUnlockChange(Sender: TObject);
begin
     btnRegister.Enabled := (Length(edtUnlock.Text) > 0);
end; {TfrmRegister.edtUnlockChange}

{*******************************************************************************
* Procedure : FormCreate                                                       *
********************************************************************************
* Purpose   : Recovers the user name from SLock                                *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.FormCreate(Sender: TObject);
begin
     edtRegName.Text := frmMain.Slock1.RegName;
end; {TfrmRegister.FormCreate}

{*******************************************************************************
* Procedure : edtRegNameChange                                                 *
********************************************************************************
* Purpose   : Resets the other input fields when the name changes              *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.edtRegNameChange(Sender: TObject);
begin
     // clear the registration information and disable
     // inputs
     edtChallengeString.Text := '';
     edtUnlock.Text := '';
     edtChallengeString.Enabled := False;
     edtUnlock.Enabled := False;
end; {TfrmRegister.edtRegNameChange}

{*******************************************************************************
* Procedure : btnPurchaseClick                                                 *
********************************************************************************
* Purpose   : Opens the browser to the KAGI site                               *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnPurchaseClick(Sender: TObject);
begin
     ShellExecute(GetDesktopWindow(), nil, PChar('http://order.kagi.com/?GDS'), nil, nil, SW_SHOWNORMAL);
end; {TfrmRegister.btnPurchaseClick}

{*******************************************************************************
* Procedure : btnTSMWebClick                                                   *
********************************************************************************
* Purpose   : Opens the browser to the TSM web site                            *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnTSMWebClick(Sender: TObject);
begin
     ShellExecute(GetDesktopWindow(), nil, PChar('http://www.crypto-central.com/index.html'), nil, nil, SW_SHOWNORMAL);
end; {TfrmRegister.btnTSMWebClick}

end.
