{*******************************************************************************
* Unit      : Defines the "Register" window                                    *
********************************************************************************
* Purpose   : This window offers various ways of requesting and retrieving     *
*             a Certificate. This can either be performed automatically by     *
*             accessing a static or dynamic web page (we use the dynamic       *
*             variation here) or by requesting the Certificate manually using  *
*             eMail.                                                           *
********************************************************************************
* Copyright : This software  is copyright TSM Inc. 1998-1999                   *
*             This source code may not be distributed to third parties in      *
*             or in part without the written permission of TSM Inc.            *
*             All rights reserved. Liability limited to replacement of         *
*             this original source code in the case of loss or damage because  *
*             the use or misuse of this software.                              *
********************************************************************************
* Version   : 14.08.99  - 2.00  PK version "SLockPK"                           *
********************************************************************************
* Switches  : None                                                             *
*******************************************************************************}
unit RegFrm;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls, ShellApi, Clipbrd;

type
  TfrmRegister = class(TForm)
    grpRegInfo: TGroupBox;
    pnlButtons: TPanel;
    btnDone: TButton;
    edtName: TEdit;
    lblName: TLabel;
    btnEnable: TButton;
    bvlStep1: TBevel;
    lblStep1: TLabel;
    btnTSMWeb: TButton;
    edtEmail: TEdit;
    lblEmail: TLabel;
    edtAddress1: TEdit;
    lblAddress1: TLabel;
    edtAddress2: TEdit;
    lblAddress2: TLabel;
    edtComment: TEdit;
    lblComment: TLabel;
    lblRegister: TLabel;
    edtProxy: TEdit;
    lblProxy: TLabel;
    edtProxyPort: TEdit;
    Label1: TLabel;
    Bevel1: TBevel;
    lblAlternative: TLabel;
    btnLoadCert: TButton;
    btnPurchase: TButton;
    Label2: TLabel;
    lblExplanation: TLabel;
    procedure btnDoneClick(Sender: TObject);
    procedure btnEnableClick(Sender: TObject);
    procedure edtNameChange(Sender: TObject);
    procedure btnPurchaseClick(Sender: TObject);
    procedure btnTSMWebClick(Sender: TObject);
    procedure btnLoadCertClick(Sender: TObject);
  end;

var
  frmRegister: TfrmRegister;

implementation

uses
     Slock, frmMain, RegFrm1;

{$R *.DFM}

{*******************************************************************************
* Procedure : TfrmRegister.btnDoneClick                                        *
********************************************************************************
* Purpose   : This closes the window                                           *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnDoneClick(Sender: TObject);
begin
     Close;
end; {TfrmRegister.btnDoneClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnEnableClick                                      *
********************************************************************************
* Purpose   : This gathers the information from the user information fields    *
*             and packs it into the user information record.                   *
*                                                                              *
*             The user information record is then encrypted using the          *
*             GetUserInfoString function which encrypts the information and    *
*             packages it ready for transmission over the net.                 *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnEnableClick(Sender: TObject);
var
     UserInfo: TUserInfo;
begin
     // set the cursor to show that we are busy
     Screen.Cursor := crHourglass;

     // create the user information record using the information given by the
     // user
     UserInfo.UserName       := edtName.Text;
     UserInfo.UserEmail      := edtEmail.Text;
     UserInfo.UserAddress    := edtAddress1.Text + ', ' + edtAddress2.Text;
     UserInfo.UserCreditCard := '';
     UserInfo.UserCCExpiry   := '';
     UserInfo.UserComment    := edtComment.Text;

     // try to register - we can either do this over the internet using the
     // test server provided by TSM, or using a local server if you have
     // purchased or requested it
     // You can set the LocalServer flag either manually or like in this example,
     // using a variable in the INI file (LocalServer: Boolean)
     if frmMainForm.LocalServer then
     begin
          // we are in debug mode, so use the local copy of the server
          // you have to request a server from TSM Inc if you want to use this
          frmMainForm.SLock1.LoadCertURL('http://localhost/cgi-bin/SSSLockTest.exe', edtProxy.Text,
                                         edtProxyPort.Text, True, UserInfo);
     end
     else
     begin
          // we are in the normal mode, so use the internet test server
          frmMainForm.SLock1.LoadCertURL('http://www.crypto-central.com/cgi-bin/SSSLockTest.exe', edtProxy.Text,
                                         edtProxyPort.Text, True, UserInfo);
     end;

     // reset the cursor
     Screen.Cursor := crDefault;
end; {TfrmRegister.btnEnableClick}

{*******************************************************************************
* Procedure : TfrmRegister.edtNameChange                                       *
********************************************************************************
* Purpose   : Enables the "Enable" and "Purchase" buttons when the minimum     *
*             required amount of info has been entered by the user.            *
*                                                                              *
*             For this example application, we will require just a name and    *
*             the email addresss. You may decide that other fields are "must"  *
*             fields for your application                                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.edtNameChange(Sender: TObject);
begin
     btnEnable.Enabled   :=  ((Length(edtName.Text) > 0) and
                             (Length(edtEmail.Text) > 0));
     btnPurchase.Enabled :=  ((Length(edtName.Text) > 0) and
                             (Length(edtEmail.Text) > 0));
     btnLoadCert.Enabled :=  ((Length(edtName.Text) > 0) and
                             (Length(edtEmail.Text) > 0));
end; {TfrmRegister.edtNameChange}

{*******************************************************************************
* Procedure : TfrmRegister.btnPurchaseClick                                    *
********************************************************************************
* Purpose   : Opens a browser window to the KAGI order site                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnPurchaseClick(Sender: TObject);
begin
     // sends the purchase information to us and takes the user to KAGI
     ShowMessage('You are about to purchase. You will be taken to our ' +
                 'online registration system where you can make the purchase. Please ' +
                 'make sure you are connected to the internet and then press OK.');

     // set the cursor
     Screen.Cursor := crHourglass;

     ShellExecute(GetDesktopWindow(), nil,
                  PChar('http://order.kagi.com/?GDS'),
                  nil, nil, SW_SHOWNORMAL);
end; {TfrmRegister.btnPurchaseClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnTSMWebClick                                      *
********************************************************************************
* Purpose   : Opens a browser window to the TSM main window                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnTSMWebClick(Sender: TObject);
begin
     ShellExecute(GetDesktopWindow(), nil,
                  PChar('http://www.crypto-central.com/index.html'),
                  nil, nil, SW_SHOWNORMAL);
end; {TfrmRegister.btnTSMWebClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnCopyToClipClick                                  *
********************************************************************************
* Purpose   : Copy the contents of the memo field to the clipboard             *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
{TfrmRegister.btnCopyToClipClick}

{*******************************************************************************
* Procedure : TfrmRegister.btnLoadCertClick                                    *
********************************************************************************
* Purpose   : Show the manual load certificate window                          *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmRegister.btnLoadCertClick(Sender: TObject);
var
     UserInfo: TUserInfo;
begin
     // create the user information record
     UserInfo.UserName := edtName.Text;
     UserInfo.UserEmail := edtEmail.Text;
     UserInfo.UserAddress := edtAddress1.Text + ', ' + edtAddress2.Text;
     UserInfo.UserCreditCard := '';
     UserInfo.UserCCExpiry := '';
     UserInfo.UserComment := edtComment.Text;

     frmLoadCert := TfrmLoadCert.Create(Application);
     frmLoadCert.mmoUIR.Text := frmMainForm.SLock1.GetUserInfoString(UserInfo);
     frmLoadCert.ShowModal;
     frmLoadCert.Free;
end; {TfrmRegister.btnLoadCertClick}

end.
