{*******************************************************************************
* Unit      : TSLockPK Demostration program "SLockServerTest"                  *
*             Uses SLockPK in the "PublicKey" registration mode, retrieving    *
*             keys from an SLock internet server. This example project is      *
*             is designed to show you the steps requried to retrieve SLockPK   *
*             Certificates from either static or dynamic http pages. This      *
*             example uses a dynamic server to compute Certificates on the fly.*
********************************************************************************
* Purpose   : Demonstration/Example program for the SLockPK component          *
*             This program is intended to provide SLockPK users with ideas     *
*             and examples how to use the SLockPK component to achieve         *
*             successful results with the SLock Certificate Server. You are at *
*             liberty to use portions of this code in your own applications    *
*             once you have purchased SLockPK.                                 *
*                                                                              *
*             This example communicates with a Certificate server, which       *
*             computes Certificates on the fly. You could also use the much    *
*             simpler alternative of retrieveing a static html page which      *
*             delivers a hard coded Trial Certificate back.                    *
*                                                                              *
*             A Certificate Server is provided for test purposes at:           *
*             "http://www.crypto-central.com/cgi-bin/SSSlockServerTest.exe"    *
*             You are at liberty to use this server. For more information,     *
*             about the parameters used by the server, please see:             *
*             "http://www.crypto-central.com/slock/TestServer.html"            *
*                                                                              *
*             Note that this application is a fairly advanced example, and     *
*             similar results can be achieved with much less code if you       *
*             wish. See the other example projects for details how to do this. *
*                                                                              *
*             Note also that the file hashing has been turned off on the       *
*             server at crypto-central.com - this is to allow you to compile   *
*             this application yourself (each time an application is compiled  *
*             under Delphi it is compiled differently - this means that each   *
*             software you support in the Certificate Server refers to         *
*             *exactly* one build.                                             *
********************************************************************************
* Copyright : This software  is copyright TSM Inc. 1998-1999                   *
*             This source code may not be distributed to third parties in      *
*             or in part without the written permission of TSM Inc.            *
*             All rights reserved. Liability limited to replacement of         *
*             this original source code in the case of loss or damage because  *
*             the use or misuse of this software.                              *
********************************************************************************
* Version   : 14.08.98  - 1.00  Original Version                               *
********************************************************************************
* Switches  : None                                                             *
*******************************************************************************}
unit frmMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ExtCtrls, Menus, Buttons,
  Slock;

type
  TfrmMainForm = class(TForm)
    MainMenu1: TMainMenu;
    mnmFile: TMenuItem;
    mnpExit: TMenuItem;
    mnmHelp: TMenuItem;
    mnpAbout: TMenuItem;
    N1: TMenuItem;
    mnpReqReg: TMenuItem;
    Slock1: TSlock;
    mnmFunction: TMenuItem;
    mnpTestFunction: TMenuItem;
    mnmDemo: TMenuItem;
    mnpDemoFunction: TMenuItem;
    grpStatus: TGroupBox;
    bvlStatus: TBevel;
    lblStatus: TLabel;
    lblStatusDisp: TLabel;
    lblRegisteredTo: TLabel;
    lblRegisteredToDisp: TLabel;
    lblSerialNumber: TLabel;
    lblSerialNumberDisp: TLabel;
    lblVersionLabel: TLabel;
    lblVersionDisp: TLabel;
    lblCertExpireDisp: TLabel;
    lblCertExpire: TLabel;
    lblUser1Label: TLabel;
    lblUser2Label: TLabel;
    lblUser1: TLabel;
    lblUser2: TLabel;
    btnExit: TButton;
    btnRegister: TButton;
    procedure FormCreate(Sender: TObject);
    procedure mnpAboutClick(Sender: TObject);
    procedure Slock1NoInitCert(Sender: TObject);
    procedure Slock1CertAccept(Sender: TObject);
    procedure Slock1CertReject(Sender: TObject);
    procedure Slock1CertExpired(Sender: TObject);
    procedure Slock1RegInfoTamper(Sender: TObject);
    procedure Slock1RegInfoChanged(Sender: TObject);
    procedure Slock1Terminate(Sender: TObject);
    procedure mnpReqRegClick(Sender: TObject);
    procedure btnRegisterClick(Sender: TObject);
    procedure btnExitClick(Sender: TObject);
    procedure Slock1Reset(Sender: TObject);
  public
     AddressList: TList;
     MailServer:  string;
     MailPort:    string;
     MailTimeOut: integer;
     MaxBCC:      integer;
     LogFileName: string;
     Debug:       Boolean;
     LocalServer: Boolean;
  private
     procedure UpdateStatus;
  end;

var
  frmMainForm: TfrmMainForm;

implementation

uses
  IniFiles, frmAbout, RegFrm1, RegFrm, frmUpd;

const
     // this is the second part of the key. See the "LockPK" example program for
     // more advanced methods of doing this.
     LIT_KEY_PART2 = '-sHep++TU32PQz+';

{$R *.DFM}

{*******************************************************************************
* Procedure : TfrmMainForm.FormCreate                                          *
********************************************************************************
* Purpose   : We check the current status of the protection in the form create *
*             of the main form. (Slock1.CheckProtection) The internal state of *
*             Slock is set, and we then use 'UpdateStatus' to read the status  *
*             of Slock out into the status display                             *
*                                                                              *
*             We also use the FormCreate procedure to set up the "nice to have"*
*             features of the protocol. For instance, the SLockPK component    *
*             can report back that a newer version of the software is          *
*             available - we allow the user to turn this notification off      *
*             by using the "CanBug" variable which is stored in an ini file.   *
*             This is not part of the SLockPK component itself, but we have    *
*             included this part of the code as a template should you wish to  *
*             use it.                                                          *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.FormCreate(Sender: TObject);
var
     IniFile: TIniFile;
     CanBug: Boolean;
begin
     // read the options out of the ini file
     IniFile := TIniFile.Create('SLockServerTest.ini');

     // the "CanBug" flag is used to control if we show the update warning
     // message or not. By default this message is shown every time. We set
     // this option to stop the message appearing until the next update
     CanBug := IniFile.ReadBool('Settings', 'InformUpdates', True);

     // The "Debug" flag allows you to inspect the input and output of the
     // SLockPK server if set. This is by default not set.
     Debug := IniFile.ReadBool('Settings', 'DebugFlag', True);

     // The "LocalServer" flag allows you to use a local Certificate Server if
     // you have one. This saves online costs!
     LocalServer := IniFile.ReadBool('Settings', 'LocalServer', False);

     // dispose of the ini file as we have now finished with it
     IniFile.Free;

     // load the SLockPK public key - see the "LockPK" example and the help file
     // for the reason that we split the key up like this.
     SLock1.LoadPKKey('++11Ik:sI08aLp' + LIT_KEY_PART2 +
                      '8YAh7uFYh3ykyaVtFNpPY1i9taYMXwrlZqCj74st168qNi6b2pokpoxDsfdVfeD+');

     // Show the version of the SLock component we are using
     lblVersionDisp.Caption := SLock1.GetVersion;

     // check the Certificate
     SLock1.CheckProtection;

     // if we are nearing the end of the Certificate, then show the request Certificate window
     if ((SLock1.CertExpire - 5) < Now) and (SLock1.Status <> stExpired) then
     begin
          ShowMessage('Your Certificate is about to or has already reached its termination date. ' +
                      'SLockServerTest will continue to function, but please register anyway! ' +
                      Chr(13) + Chr(10) + Chr(13) + Chr(10) +
                      'The registration window will now be displayed.');
          mnpReqRegClick(Self);
     end; {if}

     // check for a new version, and show if we are allowed to
     if (Slock1.NewVersionAvail and CanBug) then
     begin
          frmUpdate := TfrmUpdate.Create(Application);
          frmUpdate.ShowModal;
          frmUpdate.Free;
     end; {if}

     // Update the status display and the state of the Buttons/Menupoints
     UpdateStatus;
end; {TfrmMainForm.FormCreate}

{*******************************************************************************
* Procedure : Slock1NoInitCert                                                 *
********************************************************************************
* Purpose   : This is triggered when no initial certificate is stored in the   *
*             Registry, i.e. on the first start.                               *
*             The user must enter a valid certificate before the application   *
*             can start - he can do this either by retrieveing from a server   *
*             or a static http page, or by simply requesting per email. See    *
*             the "Registration" window for more details.                      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1NoInitCert(Sender: TObject);
begin
     ShowMessage('You need to enable SLockServerTest before it will work. To Do this, please ' +
                 'fill in your registration information. Once you have completed the ' +
                 'information, make sure you have an internet connection open and ' +
                 ' click the "Register" button.' + Chr(13) + Chr(10) + Chr(13) + Chr(10) +
                 'You will have to wait a few seconds and then you will be registered');

     // show the register window
     frmRegister := TfrmRegister.Create(Application);
     frmRegister.ShowModal;
     frmRegister.Free;
end; {TfrmMainForm.Slock1NoInitCert}

{*******************************************************************************
* Procedure : Slock1CertAccept                                                 *
********************************************************************************
* Purpose   : This is triggered when a valid certificate is presented to the   *
*             application                                                      *
*             The certificate is then stored in the registry under the CertKey,*
*             CertPath and CertRoot location.                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1CertAccept(Sender: TObject);
var
     IniFile: TIniFile;
begin
     // show the UIR and response if we are in Debug mode
     if Debug then
     begin
          ShowMessage(SLock1.GetTransmitted);
          ShowMessage(SLock1.GetReceived);
     end;

     // reset the don't bug me indicator, as we have accepted a new Certificate
     IniFile := TIniFile.Create('SLockServerTest.ini');
     IniFile.WriteBool('Settings', 'InformUpdates', True);
     IniFile.Free;

     // show the message and restart
     ShowMessage('Certificate loaded.');

     // update the status
     UpdateStatus;
end; {TfrmMainForm.Slock1CertAccept}

{*******************************************************************************
* Procedure : Slock1CertExpired                                                *
********************************************************************************
* Purpose   : This event is triggered when the expiry date of the certificate  *
*             is passed.                                                       *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1CertExpired(Sender: TObject);
begin
     ShowMessage('Your current Certificate has expired. Please request a new Certificate.');

     // show the register window
     frmRegister := TfrmRegister.Create(Application);
     frmRegister.ShowModal;
     frmRegister.Free;

     // if we get this far then no Certificate has been loaded. (If a Certificate
     // has been loaded, then the program branches to either the "CertAccept"
     // or the "CertReject" event. We *must* have a Certificate, so tell the
     // user and end.
     ShowMessage('No Certificate was loaded. A Certificate is required before SLockServerTest will run.');
     Halt;
end; {TfrmMainForm.Slock1CertExpired}

{*******************************************************************************
* Procedure : Slock1CertReject                                                 *
********************************************************************************
* Purpose   : This is triggered when an invalid certificate is presented to the*
*             application                                                      *
*             The certificate is not stored in the registry                    *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1CertReject(Sender: TObject);
begin
     // warn the user that the Certificate has been rejected
     ShowMessage('The Certificate was not valid and has not been accepted. You need ' +
                 'a valid Certificate to be able to use this application. Please ' +
                 'request a new Certificate.');

     // we cannot continue without a certificate, so end
     Halt;
end; {TfrmMainForm.Slock1CertReject}

{*******************************************************************************
* Procedure : Slock1RegInfoTamper                                              *
********************************************************************************
* Purpose   : This event is triggered when the fingerprint information in the  *
*             Certificate does not match the information from the PC, and the  *
*             threshold has been exceeded. This means that either the PC has   *
*             been extensively altered, or someone has installed on a PC       *
*             which is not authorised.                                         *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1RegInfoTamper(Sender: TObject);
begin
     ShowMessage('The Certificate does not match your PC. Please request a new Certificate.');
end; {TfrmMainForm.Slock1RegInfoTamper}

{*******************************************************************************
* Procedure : Slock1RegInfoChanged                                             *
********************************************************************************
* Purpose   : This is triggered when the registration information stored in    *
*             Windows registry is checked, and it is found that the finger-    *
*             print items no longer match the information stored in the        *
*             Certificate. The number of items which do not match is still     *
*             the level defined in the threshold, meaning that the application *
*             will still work, but will issue this message. The user should    *
*             request an updated Certificate which contains the updated        *
*             fingerprint information.                                         *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1RegInfoChanged(Sender: TObject);
begin
     ShowMessage('Your Certificate is linked to certain "fingerprint" items in your PC. ' +
                 'It looks as though you have changed some hardware. Please request a ' +
                 'new Certificate to remove this message.');
end; {TfrmMainForm.Slock1RegInfoChanged}

{*******************************************************************************
* Procedure : TfrmMainForm.Slock1Terminate                                     *
********************************************************************************
* Purpose   : This is triggered when a "Terminate" Certificate is retrieved.   *
*             The Terminate Certificate is designed to end the registration    *
*             period before the usual expiry date, for instance if a payment   *
*             defaults after being received. No further processing is performed*
*             once the Terminate Certificate is received.                      *
*             You can easily remove the Terminate condition by issuing a new   *
*             certificate with a different Certificate mode.                   *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1Terminate(Sender: TObject);
begin
     // show a user friendly message - this is deliberately slightly vague. See
     // the explanation in the comment for the real reasons why this event may
     // be triggered.
     ShowMessage('Your trial period is over - please contact TSM Inc ' +
                 '"support@crypto-central.com" for further information');

     // show the registration window so the user has a chance to request a new
     // Certificate
     frmRegister := TfrmRegister.Create(Application);
     frmRegister.ShowModal;
     frmRegister.Free;

     // if we get this far then no Certificate has been loaded. (If a Certificate
     // has been loaded, then the program branches to either the "CertAccept"
     // or the "CertReject" event. We *must* have a Certificate, so tell the
     // user and end.
     ShowMessage('No Certificate was loaded. A Certificate is required before SLockServerTest will run.');
     Halt;
end; {TfrmMainForm.Slock1Terminate}

{*******************************************************************************
* Procedure : TfrmMainForm.mnpAboutClick                                       *
********************************************************************************
* Purpose   : Displays the about window.                                       *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.mnpAboutClick(Sender: TObject);
begin
     // show the about screen
     frmAboutSLockServerTest := TfrmAboutSLockServerTest.Create(Application);
     frmAboutSLockServerTest.ShowModal;
     frmAboutSLockServerTest.Free;
end; {TfrmMainForm.mnpAboutClick}

{*******************************************************************************
* Procedure : TfrmMainForm.mnpReqRegClick                                      *
********************************************************************************
* Purpose   : Opens up the window in which the registration information can    *
*             be entered into                                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.mnpReqRegClick(Sender: TObject);
begin
     // simulate a button click
     btnRegisterClick(Sender);
end; {TfrmMainForm.mnpReqRegClick}

{*******************************************************************************
* Procedure : TfrmMainForm.btnRegisterClick                                    *
********************************************************************************
* Purpose   : Opens up the window in which the registration information can    *
*             be entered into                                                  *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.btnRegisterClick(Sender: TObject);
var
     frmRegister: TfrmRegister;
begin
     // create the registration window
     frmRegister := TfrmRegister.Create(self);

     // fill in the user name if we know it
     frmRegister.edtName.Text := SLock1.RegName;

     frmRegister.ShowModal;

     // release the window
     frmRegister.Free;

     // Update the status
     UpdateStatus;
end; {TfrmMainForm.btnRegisterClick}

{*******************************************************************************
* Procedure : TfrmMainForm.UpdateStatus                                        *
********************************************************************************
* Purpose   : Loads the internal status of the Slock component into the status *
*             display. Also sets the state of the menus and buttons            *
*                                                                              *
*             You normally do not need a function such as this, but for the    *
*             purposes of showing you how SLockPK works this is required.      *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.UpdateStatus;
begin
     // load the status display from the Status property
     case Slock1.Status of
     stNotExpired:
          lblStatusDisp.Caption := 'Not Expired';
     stExpired:
          lblStatusDisp.Caption := 'Expired';
     stGrace:
          lblStatusDisp.Caption := 'Grace Period';
     stRegistered:
          lblStatusDisp.Caption := 'Registered';
     stDemo:
          lblStatusDisp.Caption := 'Registered Demo';
     end;

     // show the certificate expiry date
     lblCertExpire.Caption := FormatDateTime('dd/mm/yyyy', SLock1.CertExpire);

     // load the registration information
     if SLock1.Registered then
     begin
          lblRegisteredToDisp.Caption := Slock1.RegName;
     end
     else
     begin
          lblRegisteredToDisp.Caption := 'N/A';
     end;

     // the serial number is a persistent field which can be set in trial mode
     lblSerialNumberDisp.Caption := Slock1.SerialNumber;

     // the user fields are persistent fields
     lblUser1.Caption := SLock1.GetUserField1;
     lblUser2.Caption := SLock1.GetUserField2;

     {set the state of the buttons/menus - these are set for this demo
     application and probably won't be the same same as for a real-life
     application}
     // the demonstration function should work until the expiry is reached
     mnmFunction.Enabled := (Slock1.Status <> stExpired);

     //The Demo function should *only* work in demo mode
     mnmDemo.Enabled := (SLock1.Status = stDemo);
end; {TfrmMainForm.UpdateStatus}

{*******************************************************************************
* Procedure : TfrmMainForm.btnExitClick                                        *
********************************************************************************
* Purpose   : Closes the program.                                              *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.btnExitClick(Sender: TObject);
begin
     Close;
end; {TfrmMainForm.btnExitClick}

{*******************************************************************************
* Procedure : TfrmMainForm.Slock1Reset                                         *
********************************************************************************
* Purpose   : Tells the user that a Reset Certificate has been received        *
********************************************************************************
* Paramters : None                                                             *
********************************************************************************
* Returns   : None                                                             *
*******************************************************************************}
procedure TfrmMainForm.Slock1Reset(Sender: TObject);
begin
     ShowMessage('A reset Certificate has been received - SLockPK has reset the registration.');
     Halt;
end; {TfrmMainForm.Slock1Reset}

end.
